#![doc = include_str!("../README.md")]
//!
//! ----
//!
//! _documents in the library_
//!
//! Generate register interface software from register map in XML.
//!
//! # Example
//!
//! See [`generate`].
//!
//! # Overview
//!
//! 1. Convert [`roxmltree::Document`] to register map represented with types defined in
//!    [`types`], filling missing parameters. See [`converter`].
//! 2. Validate the register map. See [`types::Module::validate`] in [`validator`].
//! 3. Generate [`proc_macro2::TokenStream`] from register map produced in the previous step. See
//!    [`generator`].
//!
//! # modules
//! - [`types`]: type definitions of internal register map representation
//! - [`converter`]: DOM to internal representation
//! - [`generator`]: internal representation to rust code
//! - [`io`]: formatting and printing
//! - [`validator`]: validate the register map and generate flattened register map

pub mod converter;
pub mod generator;
pub mod integrated;
pub mod io;
pub mod meta;
mod parser;
mod type_traits;
pub mod types;
pub mod validator;

pub use integrated::generate;
pub use io::write_to_files;
